@@ -10,20 +10,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.load_balancer import load_balancer_service as lb_service
 from openstack import resource
 
 
-class Listener(resource.Resource):
+class Listener(resource.Resource, resource.TagMixin):
     resource_key = 'listener'
     resources_key = 'listeners'
-    base_path = '/v2.0/lbaas/listeners'
-    service = lb_service.LoadBalancerService()
+    base_path = '/lbaas/listeners'
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
@@ -35,6 +33,7 @@ class Listener(resource.Resource):
         'timeout_client_data', 'timeout_member_connect',
         'timeout_member_data', 'timeout_tcp_inspect',
         is_admin_state_up='admin_state_up',
+        **resource.TagMixin._tag_query_parameters
     )
 
     # Properties
@@ -90,3 +89,29 @@ class Listener(resource.Resource):
     #: Time, in milliseconds, to wait for additional TCP packets for content
     #: inspection.
     timeout_tcp_inspect = resource.Body('timeout_tcp_inspect', type=int)
+
+
+class ListenerStats(resource.Resource):
+    resource_key = 'stats'
+    base_path = '/lbaas/listeners/%(listener_id)s/stats'
+
+    # capabilities
+    allow_create = False
+    allow_fetch = True
+    allow_commit = False
+    allow_delete = False
+    allow_list = False
+
+    # Properties
+    #: The ID of the listener.
+    listener_id = resource.URI('listener_id')
+    #: The currently active connections.
+    active_connections = resource.Body('active_connections', type=int)
+    #: The total bytes received.
+    bytes_in = resource.Body('bytes_in', type=int)
+    #: The total bytes sent.
+    bytes_out = resource.Body('bytes_out', type=int)
+    #: The total requests that were unable to be fulfilled.
+    request_errors = resource.Body('request_errors', type=int)
+    #: The total connections handled.
+    total_connections = resource.Body('total_connections', type=int)
