@@ -10,19 +10,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.network import network_service
 from openstack import resource
 
 
 class ServiceProvider(resource.Resource):
     resources_key = 'service_providers'
     base_path = '/service-providers'
-    service = network_service.NetworkService()
 
     # Capabilities
     allow_create = False
-    allow_get = False
-    allow_update = False
+    allow_fetch = False
+    allow_commit = False
     allow_delete = False
     allow_list = True
 
